.. role:: hidden
    :class: hidden-section

apex.parallel
===================================

.. automodule:: apex.parallel
.. currentmodule:: apex.parallel

.. DistributedDataParallel
   ----------

.. autoclass:: DistributedDataParallel
    :members:

.. autoclass:: Reducer
    :members:

.. autoclass:: SyncBatchNorm
    :members:

Utility functions
----------------------------------

.. autofunction:: convert_syncbn_model
